@@ -1,4 +1,4 @@
-__version__ = "0.1.1"
+__version__ = "0.1.4"
 __author__ = "@obahamonde"
 __license__ = "MIT"
 
@@ -11,4 +11,14 @@ from faunadb.objects import _Expr, Ref, Query, FaunaTime, SetRef
 from faunadb.client import FaunaClient
 from aiohttp import ClientSession
 from pydantic import BaseModel, Field, EmailStr, HttpUrl, validator, ValidationError
-from typing import Any, List, Optional, Union, Dict, Generator, Callable, AsyncGenerator, AsyncContextManager
\ No newline at end of file
+from typing import (
+    Any,
+    List,
+    Optional,
+    Union,
+    Dict,
+    Generator,
+    Callable,
+    AsyncGenerator,
+    AsyncContextManager,
+)
