@@ -31,6 +31,7 @@ class Environment(BaseSettings):
 
 env = Environment()
 
+
 class FaunaModel(JSONModel):
     """FaunaDB Model"""
 
@@ -115,7 +116,7 @@ class FaunaModel(JSONModel):
             data = cls.q()(
                 q.get(q.match(q.index(f"{cls.__name__.lower()}_{field}_unique"), value))
             )
-            return cls(**{**data["data"], "ref": data["ref"].id(), "ts": data["ts"]})
+            return cls(**{**data["data"], "ref": data["ref"].id(), "ts": data["ts"]/1000})
         except FaunaError as exc:
             print(exc)
             return None
@@ -130,7 +131,7 @@ class FaunaModel(JSONModel):
             )["data"]
             for ref in refs:
                 data = _q(q.get(ref))
-                yield cls(**{**data["data"], "ref": data["ref"].id(), "ts": data["ts"]})
+                yield cls(**{**data["data"], "ref": data["ref"].id(), "ts": data["ts"]/1000})
         except FaunaError as exc:
             print(exc)
             return None
@@ -140,7 +141,7 @@ class FaunaModel(JSONModel):
         """Find a document by id"""
         try:
             data = cls.q()(q.get(q.ref(q.collection(cls.__name__.lower()), ref)))
-            return cls(**{**data["data"], "ref": data["ref"].id(), "ts": data["ts"]})
+            return cls(**{**data["data"], "ref": data["ref"].id(), "ts": data["ts"]/1000})
         except FaunaError as exc:
             print(exc)
             return None
@@ -153,7 +154,7 @@ class FaunaModel(JSONModel):
             refs = _q(q.paginate(q.match(q.index(cls.__name__.lower()))))["data"]
             for ref in refs:
                 data = _q(q.get(ref))
-                yield cls(**{**data["data"], "ref": data["ref"].id(), "ts": data["ts"]})
+                yield cls(**{**data["data"], "ref": data["ref"].id(), "ts": data["ts"]/1000})
         except FaunaError as exc:
             print(exc)
             return None
@@ -209,7 +210,7 @@ class FaunaModel(JSONModel):
                     q.ref(q.collection(cls.__name__.lower()), ref), {"data": kwargs}
                 )
             )
-            return cls(**{**data["data"], "ref": data["ref"].id(), "ts": data["ts"]})
+            return cls(**{**data["data"], "ref": data["ref"].id(), "ts": data["ts"]/1000})
         except FaunaError as exc:
             print(exc)
             return None
@@ -231,7 +232,7 @@ class FaunaModel(JSONModel):
             refs = cls.q()(q.paginate(q.match(q.query(query))))["data"]
             for ref in refs:
                 data = cls.q()(q.get(ref))
-                yield cls(**{**data["data"], "ref": data["ref"].id(), "ts": data["ts"]})
+                yield cls(**{**data["data"], "ref": data["ref"].id(), "ts": data["ts"]/1000})
         except FaunaError as exc:
             print(exc)
             return None
@@ -239,7 +240,8 @@ class FaunaModel(JSONModel):
 class AsyncFaunaModel(JSONModel):
     """FaunaDB Model"""
     ref: Optional[str] = None
-
+    ts: Optional[int] = None
+    
     @classmethod
     def client(cls) -> AsyncFaunaClient:
         """Return a FaunaClient"""
@@ -295,15 +297,16 @@ class AsyncFaunaModel(JSONModel):
                     )
                     print(f"Created index {cls.__name__.lower()}_{field.name}")
                     continue
-        except FaunaError as exc:
+        except (FaunaError, KeyError, IndexError, ValueError, EOFError, ModuleNotFoundError,TypeError,Exception) as exc:
             print(exc)
+            return None
 
     @classmethod
     async def exists(cls, ref: str) -> Optional[bool]:
         """Check if a document exists"""
         try:
             return await cls.q()(q.exists(q.ref(q.collection(cls.__name__.lower()), ref)))
-        except FaunaError as exc:
+        except (FaunaError, KeyError, IndexError, ValueError, EOFError, ModuleNotFoundError,TypeError,Exception) as exc:
             print(exc)
             return None
 
@@ -314,8 +317,8 @@ class AsyncFaunaModel(JSONModel):
             data = await cls.q()(
                 q.get(q.match(q.index(f"{cls.__name__.lower()}_{field}_unique"), value))
             )
-            return cls(**{**data["data"], "ref": data["ref"].id(), "ts": data["ts"]/1000})
-        except FaunaError as exc:
+            return cls(**{**data["data"], "ref": data["ref"]["@ref"]["id"], "ts": data["ts"]/1000})
+        except (FaunaError, KeyError, IndexError, ValueError, EOFError, ModuleNotFoundError,TypeError,Exception) as exc:
             print(exc)
             return None
 
@@ -327,11 +330,11 @@ class AsyncFaunaModel(JSONModel):
             refs = (await _q(
                 q.paginate(q.match(q.index(f"{cls.__name__.lower()}_{field}"), value))
             ))["data"]
-            data = await asyncio.gather(*[_q(q.get(ref)) for ref in refs])
+            data = await asyncio.gather(*[_q(q.get(q.ref(q.collection(cls.__name__.lower()), ref['@ref']['id']))) for ref in refs])
             return [
-                cls(**{**d["data"], "ref": d["ref"].id(), "ts": d["ts"]/1000}) for d in data
-            ]
-        except FaunaError as exc:
+                cls(**{**d["data"], "ref": d["ref"]["@ref"]["id"], "ts": d["ts"]/1000}) for d in data
+            ]   
+        except (FaunaError, KeyError, IndexError, ValueError, EOFError, ModuleNotFoundError,TypeError,Exception) as exc:
             print(exc)
             return None
 
@@ -340,8 +343,8 @@ class AsyncFaunaModel(JSONModel):
         """Find a document by id"""
         try:
             data = await cls.q()(q.get(q.ref(q.collection(cls.__name__.lower()), ref)))
-            return cls(**{**data["data"], "ref": data["ref"].id(), "ts": data["ts"]/1000})
-        except FaunaError as exc:
+            return cls(**{**data["data"], "ref": data["ref"]["@ref"]["id"], "ts": data["ts"]/1000})
+        except (FaunaError, KeyError, IndexError, ValueError, EOFError, ModuleNotFoundError,TypeError,Exception) as exc:
             print(exc)
             return None
 
@@ -351,14 +354,16 @@ class AsyncFaunaModel(JSONModel):
         try:
             _q = cls.q()
             refs = (await _q(q.paginate(q.match(q.index(cls.__name__.lower())))))["data"]
-            data = await asyncio.gather(*[_q(q.get(ref)) for ref in refs])
+            data = await asyncio.gather(*[_q(q.get(q.ref(q.collection(cls.__name__.lower()), ref['@ref']['id']))) for ref in refs])
             return [
-                cls(**{**d["data"], "ref": d["ref"].id(), "ts": d["ts"]/1000}) for d in data
+                cls(**{**d["data"], "ref": d["ref"]["@ref"]["id"], "ts": d["ts"]/1000}) for d in data
             ]
-        except FaunaError as exc:
+
+        except (FaunaError, KeyError, IndexError, ValueError, EOFError, ModuleNotFoundError,TypeError,Exception) as exc:
             print(exc)
             return None
 
+
     @classmethod
     async def delete_unique(cls, field: str, value: Any) -> bool:
         """Delete a document by a unique field"""
@@ -369,33 +374,39 @@ class AsyncFaunaModel(JSONModel):
             )
             await _q(q.delete(ref))
             return True
-        except FaunaError:
+        except (FaunaError, KeyError, IndexError, Exception) as exc:
+            print(exc)
             return False
-
     @classmethod
     async def delete(cls, ref: str) -> bool:
         """Delete a document by id"""
         try:
             await cls.q()(q.delete(q.ref(q.collection(cls.__name__.lower()), ref)))
             return True
-        except FaunaError:
+        except (FaunaError, KeyError, IndexError, ValueError, EOFError, ModuleNotFoundError,TypeError,Exception) as exc:
+            print(exc)
+            return False
+
             return False
 
     async def create(self) -> Optional[AsyncFaunaModel]:
         """Create a document"""
         try:
-           
+            for field in self.__fields__.values():
+                if field.field_info.extra.get("unique"):
+                    instance = await self.find_unique(field.name, self.dict()[field.name])
+                    if instance:
+                        return instance
             data = await self.q()(
                 q.create(
                     q.collection(self.__class__.__name__.lower()), {"data": self.dict()}
                 ))
-            
-            return data
-
-        except FaunaError as exc:
+            return self.__class__(**{**data["data"], "ref": data["ref"]["@ref"]["id"], "ts": data["ts"]/1000})
+        except (FaunaError, KeyError, IndexError, ValueError, EOFError, ModuleNotFoundError,TypeError,Exception) as exc:
             print(exc)
             return None
 
+        
     @classmethod
     async def update(cls, ref: str, **kwargs) -> Optional[AsyncFaunaModel]:
         """Update a document"""
@@ -405,21 +416,23 @@ class AsyncFaunaModel(JSONModel):
                     q.ref(q.collection(cls.__name__.lower()), ref), {"data": kwargs}
                 )
             )
-            return cls(**{**data["data"], "ref": data["ref"].id(), "ts": data["ts"]})
-        except FaunaError as exc:
+            return cls(**{**data["data"], "ref": data["ref"]["@ref"]["id"], "ts": data["ts"]/1000})
+        except (FaunaError, KeyError, IndexError, ValueError, EOFError, ModuleNotFoundError,TypeError,Exception) as exc:
             print(exc)
             return None
 
+
     async def upsert(self) -> Optional[AsyncFaunaModel]:
         """Upsert a document"""
         try:
             if not self.ref:
                 return await self.create()
             return await self.update(self.ref, **self.dict())
-        except FaunaError as exc:
+        except (FaunaError, KeyError, IndexError, ValueError, EOFError, ModuleNotFoundError,TypeError,Exception) as exc:
             print(exc)
             return None
 
+
     @classmethod
     async def query(cls, query: str) -> Optional[List[AsyncFaunaModel]]:
         """Run a query"""
@@ -427,8 +440,9 @@ class AsyncFaunaModel(JSONModel):
             refs = (await cls.q()(q.paginate(q.match(q.query(query)))))["data"]
             data = await asyncio.gather(*[cls.q()(q.get(ref)) for ref in refs])
             return [
-                cls(**{**d["data"], "ref": d["ref"].id(), "ts": d["ts"]/1000}) for d in data
+                cls(**{**d["data"], "ref": d["ref"]["@ref"]["id"], "ts": d["ts"]/1000}) for d in data
             ]
-        except FaunaError as exc:
+        
+        except (FaunaError, KeyError, IndexError, ValueError, EOFError, ModuleNotFoundError,TypeError,Exception) as exc:
             print(exc)
             return None
